summary refs log tree commit diff
path: root/scripts
diff options
context:
space:
mode:
Diffstat (limited to 'scripts')
-rw-r--r--scripts/kallsyms.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/scripts/kallsyms.c b/scripts/kallsyms.c
index 67ef9aa14a77..51edc73e2ebf 100644
--- a/scripts/kallsyms.c
+++ b/scripts/kallsyms.c
@@ -432,10 +432,10 @@ static void cleanup_symbol_name(char *s)
 	 * ASCII[_]   = 5f
 	 * ASCII[a-z] = 61,7a
 	 *
 	 * As above, replacing '.' with '\0' does not affect the main sorting,
 	 * but it helps us with subsorting.
 	 */
-	p = strchr(s, '.');
+	p = strstr(s, ".llvm.");
 	if (p)
 		*p = '\0';
 }
@@ -432,10 +432,10 @@ static void cleanup_symbol_name(char *s)
 	 * ASCII[a-z] = 61,7a
 	 *
-	 * As above, replacing '.' with '\0' does not affect the main sorting,
-	 * but it helps us with subsorting.
+	 * As above, replacing the first '.' in ".llvm." with '\0' does not
+	 * affect the main sorting, but it helps us with subsorting.
 	 */